@@ -1,6 +1,6 @@
 #encoding:utf-8
 
-""" project class
+""" Project class
 """
 
 import types
@@ -13,10 +13,21 @@ from fieldcls import *
 from expercls import *
 
 
+# ---- temporary classes for old code warnings -----
+
+class project(object):
+
+  def __init__(self,path=home_path, expnames = ['*'], varnames = [],msk_grid = 'UVic2.8_t', name = None, nonick = False, descr = None, verbose = False):
+    """
+    In case user tries to invoke class by old name
+    """
+
+    raise Exception('sg.project now depreciated. Use sg.Project. All class names now use capital convention.')
+
 
 # ---------------- Class definition for projects -----------
 
-class project:
+class Project(object):
 
   def __repr__(self):
     return self.name
@@ -28,19 +39,19 @@ class project:
   def __init__(self,path=home_path, expnames = ['*'], varnames = [],msk_grid = 'UVic2.8_t', name = None, nonick = False, descr = None, verbose = False):
 
     """
-    Initialize project object.
+    Initialize Project object.
 
     Inputs:
 
-    path	path to the project directory (e.g. /home/me/PROJECTS/test_project/). Default is sg.home_path
+    path	path to the Project directory (e.g. /home/me/PROJECTS/test_project/). Default is sg.home_path
     expnames	filter on experiment names to load
     varnames    list of variables to be loaded (can also be done later after init)
-    nonick 	Switch whether to look for a projname text file inside the project directory to obtain project nickname. True/ False
+    nonick 	Switch whether to look for a projname text file inside the Project directory to obtain Project nickname. True/ False
 
 
     Example use:
     D = sg.info()	# obtain dictionary of nicknames vs full paths
-    P = sg.project(D['my_project'])
+    P = sg.Project(D['my_project'])
     
     
     """
@@ -57,7 +68,7 @@ class project:
 
       if name is None:
 
-        # if nonick is selected, a project nickname file (usually projname) is not required.
+        # if nonick is selected, a Project nickname file (usually projname) is not required.
         if nonick:
           try:
             with open(os.path.join(self.path, projnickfile  )  ) as f:
@@ -78,7 +89,7 @@ class project:
  
     # sniff out the netcdf situation:
     
-       # find a list of the directories in the project path that qualify as experiment data dirs, i.e. contain .nc or .cdf files: 
+       # find a list of the directories in the Project path that qualify as experiment data dirs, i.e. contain .nc or .cdf files: 
     DL = isexpdir(self.path) 
     # Filter experiment names list against expnames filter argument:
 
@@ -95,7 +106,7 @@ class project:
  
     if expnames:
       self.adexp(expnames)
-      # after the experiments have been loaded, their coord elements are all different objects. So check if some of them should be the same object:
+      # after the experiments have been loaded, their Coord elements are all different objects. So check if some of them should be the same object:
       for le in self.expers:
         for re in self.expers:
         # if axes between experiments are different objects but have identical attribute values, make the objects identical. If they only have the same axis attribute value, make them equivalent. 
@@ -106,7 +117,7 @@ class project:
         # make a handy dictionary for easy reference
         self.expers[e].coords = {c.name:c for c in self.expers[e].cstack}
 
-      # at this stage of the loading process, the coord elements in the experiment cstack attributes (lists) have an axis attribute, but they are only the strings (e.g. 'X','Y','Z') obtained from the netcdf file. Next, we will replace these string instances with axis objects (defined as a class in sg) with their name attributes being the original strings (e.g. 'X'). Here, as with coords above, we need to be carefully to make those objects the same objects (in memory) if they are equal according to the & method criteria (equal name, values etc, but possibly different objects in memory). So: if a&b True, then b is replaced with a in the list). 
+      # at this stage of the loading process, the Coord elements in the experiment cstack attributes (lists) have an axis attribute, but they are only the strings (e.g. 'X','Y','Z') obtained from the netcdf file. Next, we will replace these string instances with axis objects (defined as a class in sg) with their name attributes being the original strings (e.g. 'X'). Here, as with coords above, we need to be carefully to make those objects the same objects (in memory) if they are equal according to the & method criteria (equal name, values etc, but possibly different objects in memory). So: if a&b True, then b is replaced with a in the list). 
       # So, replace axis string attribute with object attribute and obtain corresponding accumulated list of axis objects. We do this using the make_axis function:
        
       L = make_axes([ c for e in self.expers for c in self.expers[e].cstack ])
@@ -121,14 +132,14 @@ class project:
 
       # axis objects have now been created based on information in the netcdf files.
       # the exper objects now have a list of axis objects as an attribute, these should normally be identical for all experiments.
-      # each coord object in each cstack attached to each exper object now also has an axis object associated with it.
+      # each Coord object in each cstack attached to each exper object now also has an axis object associated with it.
 
       # now that the axis objects have been created, we can attempt to assign display names to them, to be used in plotting etc.
 
      
-      for l in L:
-        if l.name in ax_disp_names:
-          l.display_name = ax_disp_names[l.name]
+      for ax_elem in L:
+        if ax_elem.name in ax_disp_names:
+          ax_elem.long_name = ax_disp_names[ax_elem.name]
         
 
     if msk_grid:
@@ -140,7 +151,7 @@ class project:
         print 'Trying to read mask using ' + y_name +', ' + x_name + ' for mask.'
         self.masks = read_masks(self.path +mask_dir, grids = [self[ename].coords[y_name]*self[ename].coords[x_name] for ename in self.expers] ) 
       except:    
-        print '...no masks read in project init.'
+        print '...no masks read in Project init.'
 
     if varnames:
       self.load(varnames)
@@ -153,9 +164,9 @@ class project:
 
   def ls(self):
     """
-    Method of project class to display experiments in columns.
+    Method of Project  to display experiments in columns.
     """
-    RP = report()
+    RP = Report()
 
     RP.echo(self.expers.keys(),delim='\t')   
  
@@ -163,7 +174,7 @@ class project:
 
   def get(self, expnames, varnames):
     """
-    Project method to fetch fields from a project.
+    Project method to fetch fields from a Project.
     """
     
     fields = []
@@ -192,23 +203,23 @@ class project:
       print "No fields found. Try P.load(%s)"%varnames
     else:
       if len(fields) == 1:
-# if only single field found, return that field and not a list of fields.
+# if only single Field found, return that Field and not a list of fields.
         fields =fields[0]
 
     return fields    
 
-  # --> method belongs to project	    
+  # --> method belongs to Project	    
   def ad_mask(self,sub_dir = mask_dir,grid = False, msk_val = 2):
 
-#    print read_masks(self.path + sub_dir, grid = grid, msk_val = msk_val, parent = self)
-    self.masks = read_masks(self.path + sub_dir, grid = grid, msk_val = msk_val, parent = self)
+#    print read_masks(self.path + sub_dir, grid = grid, msk_val = msk_val)
+    self.masks = read_masks(self.path + sub_dir, grid = grid, msk_val = msk_val)
 
     
   def __getitem__(self,val):
     """
     Returns an exper object by the name of key k
     """
-# --> method belongs to project
+# --> method belongs to Project
  
     if val in self.expers.keys():
       return self.expers[val]
@@ -219,13 +230,13 @@ class project:
       raise Exception("io: exper %s not loaded." % val)
 
 
-# --> belongs to project      
+# --> belongs to Project      
   def show(self): 
     """
-    Display summary of experiments and fields loaded in project.
+    Display summary of experiments and fields loaded in Project.
     """
 
-    RP = report('---- %s ----\n'%self.name)
+    RP = Report('---- %s ----\n'%self.name)
 #    RP.echo('Experiments: ')
     explist = self.expers.keys()
     explist.sort()
@@ -234,7 +245,7 @@ class project:
 
     if not(self.expers.keys()):
 
-      RP.echo('No experiments in project.')
+      RP.echo('No experiments in Project.')
       print RP.value
       return
 
@@ -255,7 +266,7 @@ class project:
 
     """
 
- # --> belongs to project
+ # --> belongs to Project
 
     exps = self.expers 
     if expname == '':
@@ -272,7 +283,7 @@ class project:
     else:
       return False
 
- # --> belongs to project
+ # --> belongs to Project
  
   def delvar(self,varname):
     if self.expers: 
@@ -301,18 +312,18 @@ class project:
     self.update_nbytes()
 
 
-# --> belongs to class "project"
+# --> belongs to Project
 
   def adexp(self, expnames=['*'], descr = 'An experiment.'):
     """
-    Adds an experiment class to this project. Also looks for a sub-directory "masks" for masks. If it can't find that, it will use the mask inherited from the project.
+    Adds an experiment  to this Project. Also looks for a sub-directory "masks" for masks. If it can't find that, it will use the mask inherited from the Project.
     """
 
     # Convert argument expnames to list if it is not yet a list, e.g. 'flx_BL' to ['flx_BL']
     if not(isinstance(expnames,types.ListType)):
       expnames = [ expnames ]
     
-    # find a list of the directories in the project path that qualify as experiment data dirs. 
+    # find a list of the directories in the Project path that qualify as experiment data dirs. 
     DL = isexpdir(self.path)
     
     # match the argument expnames against DL via wildcard expansion etc.
@@ -329,48 +340,48 @@ class project:
 
       cstack = cdfsniff(os.path.join(self.path, expname) )
 
-      self.expers[expname] = exper(path = self.path,name = expname, cstack = cstack, descr = descr, parent = self)
+      self.expers[expname] = Exper(path = self.path,name = expname, cstack = cstack, descr = descr)
 
     self.update_nbytes()
     return 
 
   def load(self, varnames, descr = 0,chk_loaded = False, ax=None, name_suffix='_cat', new_coord_name = 'gamma', new_coord= None ):
-# -->This load belongs to the project class. It calls the load method of the exper class. 
+# -->This load belongs to Project. It calls the load method of the Exper. 
 # slices argument value is just an example
     """
-    Method of project class. E.g. P.load('salinity') for project P.
-    Loads a variable (or list of variables) for all experiments belonging to the project instance.
+    Method of Project. E.g. P.load('salinity') for Project P.
+    Loads a variable (or list of variables) for all experiments belonging to the Project instance.
     E.g. 
     
     P.load('salinity')
     E = P['CNTRL_2200p']	# pick this particular experiment
-    S = E['salinity']		# create field object and assign it to S
+    S = E['salinity']		# create Field object and assign it to S
     
    
-    chk_loaded = True (default False) makes load method check whether the field is already loaded. If so, it is not loaded.
+    chk_loaded = True (default False) makes load method check whether the Field is already loaded. If so, it is not loaded.
     
     """
 
 # errno is returned by this method and gives information about errors encountered in this method.    
     errno = 0
 
-# list functionality only exists at the level of the "project" class.
+# list functionality only exists at the level of the Project .
     if not(isinstance(varnames, list)):
       varnames = [ varnames]
    
     for varname in varnames:
  
-# Test if experiments have been registered with the project:    
+# Test if experiments have been registered with the Project:    
       if not(self.expers):
         print "No experiments." 
 # errno signifies that there are no experiments to load for.
         errno = 1
       else:
 
-# See if chk_loaded is set. If so, check whether the field is already loaded for the fist experiment.
+# See if chk_loaded is set. If so, check whether the Field is already loaded for the fist experiment.
 # If so, do not attempt to load again (but keep what's been loaded).
         if chk_loaded:
-# chk_loaded flags whether it should be checked whether the field is already loaded. Usually False.
+# chk_loaded flags whether it should be checked whether the Field is already loaded. Usually False.
           if self.loaded(varname):
             # This error number signifies a warning, and means that the variable is already loaded.
             errno = -1
@@ -387,7 +398,7 @@ class project:
 
   def write(self, path = None, name = None, force = False , history = 'Created from Spacegrids ', insert_dual = True  ): 
     """
-    Write entire loaded project to disk. 
+    Write entire loaded Project to disk. 
     """     
 
 
@@ -405,10 +416,10 @@ class project:
 
     if not(force):
       if os.path.samefile(path , self.path ):
-        print 'Refusing to write project %s to own path at risk of overwriting data. Use different path or set force = True'%name
+        print 'Refusing to write Project %s to own path at risk of overwriting data. Use different path or set force = True'%name
         return
 
-    # write project name text file:
+    # write Project name text file:
     with open(os.path.join( path, projnickfile ),'w') as f:    
       f.write(name)
 
@@ -428,7 +439,7 @@ class project:
 	
     return flag	
     
-  def report(self, varname):
+  def Report(self, varname):
     
     if not(self.expers):
       print "No experiments." 
@@ -444,7 +455,7 @@ class project:
 
   def update_nbytes(self):
     """
-    Update estimate of number of Mb used by project.
+    Update estimate of number of Mb used by Project.
     """
     if len(self.expers.values() ) > 0:
       self.nbytes = reduce( lambda x,y: x + y, [e.nbytes for e in self.expers.values()]  )
@@ -457,11 +468,11 @@ class project:
   def cat(self, fld_name, new_ax_name = 'exper', new_coord_name = None, new_coord = None):
 
     """
-    Concatenate the field fld_name for all experiments where that field is loaded.
+    Concatenate the Field fld_name for all experiments where that Field is loaded.
   
     If new_coord coord object argument is given, other arguments are overridden and that argument is used as the new coord along which the different experiments are lined up.
 
-    if no new_coord argument is given, a new coord will be constructed.
+    if no new_coord argument is given, a new Coord will be constructed.
  
     """
 
@@ -475,7 +486,7 @@ class project:
       fields = [self.expers[e].vars[fld_name] for e in e_loaded]
     
       if len(fields) != len(new_coord):
-        raise Exception('Provide equal amount of loaded field instances to length new_coord')
+        raise Exception('Provide equal amount of loaded Field instances to length new_coord')
 
       # EXIT POINT
       return concatenate(fields,  new_coord = new_coord)
@@ -490,19 +501,19 @@ class project:
 
     fields = [self.expers[e].vars[fld_name] for e in e_loaded]
 
-    new_axis = ax(new_ax_name)   
+    new_axis = Ax(new_ax_name)   
     new_coord_value = np.arange(len(fields))
-    new_coord = coord(name = new_coord_name , value = new_coord_value, axis = new_axis, direction = new_axis.name, strings = e_loaded )
+    new_coord = Coord(name = new_coord_name , value = new_coord_value, axis = new_axis, direction = new_axis.name, strings = e_loaded )
 
     # EXIT POINT  
     return concatenate(fields,  new_coord = new_coord)
 
 
-  def param2gr(self, param_name, func, name_filter = None, sort = True, new_ax_name = None, add2cstack = True):
+  def param2gr(self, param_name, func, name_filter = None, sort = True, new_Ax_name = None, add2cstack = True):
     """
-    Use a param from the experiments to construct a coord, and so construct a new concatenated field defined on a new grid with this new coord.
+    Use a param from the experiments to construct a Coord, and so construct a new concatenated Field defined on a new grid with this new Coord.
 
-    func is a function that must yield a field and take an exper object as argument.
+    func is a function that must yield a Field and take an Exper object as argument.
     it should return None for elements that are not desired. This method is somewhat different from its near-opposite method insert, where the function argument is allowed to yield fields or single values (float/ int).
 
     """
@@ -527,7 +538,7 @@ class project:
       pairs.sort()
 
 
-    new_ax = ax(new_ax_name)
+    new_ax = Ax(new_ax_name)
 
     if add2cstack:
       for E in self.expers.values():
@@ -542,9 +553,9 @@ class project:
         if not new_ax in self.expers.values()[0].axes:
           self.expers.values()[0].axes.append(new_ax)  
 
-    func = lambda x:np.nan if x is None else x 
+    def func(x): return np.nan if x is None else x 
 
-    new_coord = coord(name = new_coord_name, value = np.array( [func(e[0]) for e in pairs] ), axis = new_ax, direction = new_ax.name)
+    new_coord = Coord(name = new_coord_name, value = np.array( [func(e[0]) for e in pairs] ), axis = new_ax, direction = new_ax.name)
 
     if add2cstack:
       for E in self.expers.values():
@@ -563,7 +574,7 @@ class project:
 
   def insert(self, func, param_name= None):
     """
-    Apply function func to each exper object in self and insert the result. The result must be a tuple (name, value) or a list of such tuples (as taken by the exper insert method). Conform the exper insert method, name must be a string, and value a field or ordinary float/ int kind of datatype.
+    Apply function func to each Exper object in self and insert the result. The result must be a tuple (name, value) or a list of such tuples (as taken by the Exper insert method). Conform the Exper insert method, name must be a string, and value a Field or ordinary float/ int kind of datatype.
 
    
     """
@@ -580,18 +591,18 @@ class project:
 
     return self.param2gr(parname , lambda x:x[fld_name], name_filter = name_filter) 
 
-# ---------------- End class definition for projects -----------
+# ---------------- End  definition for projects -----------
 
 
-# -------- exper helper functions to be used with insert method ------------
+# -------- Exper helper functions to be used with insert method ------------
 
 def read_control_func(filename):
   """
-  function that yields a useful function that can be used in the project insert method: it reads a control file in the MOM 2 control file format (as used by UVic) and outputs it in the list of (name, value) tuples format required by the exper insert method. Think of it as inserting a parameter to each exper, although it can be a field too.
+  function that yields a useful function that can be used in the Project insert method: it reads a control file in the MOM 2 control file format (as used by UVic) and outputs it in the list of (name, value) tuples format required by the Exper insert method. Think of it as inserting a parameter to each Exper, although it can be a Field too.
 
   The argument filename is the file name of the control file to be read, usually control.in.
 
-  For example: P.insert(sg.read_control_func('control.in')) goes through all experiment directories and looks for, and parses, the file control.in, and then inserts the result as exper parameters.
+  For example: P.insert(sg.read_control_func('control.in')) goes through all experiment directories and looks for, and parses, the file control.in, and then inserts the result as Exper parameters.
 
   The user could construct similar functions for their own use: the function must take an experiment as argument, and return None or a list of (name, value) pairs (2 tuples).
 
@@ -666,13 +677,13 @@ def avg_temp(P, varname = 'O_temp'):
 # ------- general functions -----------
 
 def overview():
-  RP = report()
+  RP = Report()
   RP.echoln("Quick start instructions.")
   RP.line()
   RP.echoln()
   RP.echoln("# To get started: ")
   RP.echoln("D = sg.info(nonick = True)	# look for projects in ~/PROJECTS/")
-  RP.echoln("P = sg.project(D['my_project'] , nonick = True)	# init project")
+  RP.echoln("P = sg.Project(D['my_project'] , nonick = True)	# init Project")
   RP.echoln("P.load(['temperature','u'])     # load some variables into mem")
   RP.echoln("for c in P['some_experiment'].axes:   ")
   RP.echoln("  exec c.name + ' = c'	# bring axes names into namespace")
@@ -684,29 +695,29 @@ def overview():
   RP.echoln("U = P['some_experiment']['u']   ")
   RP.echoln("TEMP_sliced = TEMP[Y,:50]     ")
   RP.echoln("m_TEMP = TEMP_sliced/(X*Y)   ")
-  RP.echoln("TEMP_regridded = TEMP(U.gr)	   ")
+  RP.echoln("TEMP_regridded = TEMP(U.grid)	   ")
   RP.echoln("   ")
 
   print RP.value
 
 def ls(rootdir = os.environ['HOME'], projdirname = 'PROJECTS',fname = projnickfile, nonick = False):
   """
-  Simple function to display all project directories so that no specific paths need to be used, and projects can be referred to by their nicknames defined in a file called projname in each directory containing the experiment directories.
+  Simple function to display all Project directories so that no specific paths need to be used, and projects can be referred to by their nicknames defined in a file called projname in each directory containing the experiment directories.
  
   Inputs: 
   top		(default '~/PROJECTS/') the start dir
   fname		(default projname) the filename to look for and read the content of
   
-  displays all project (nick)names
+  displays all Project (nick)names
     
-  If nonick is False: finds all dir paths with file called fname in them, reads that file for each dir to find the nickname of that project. Otherwise just lists the subdirectories of projects dir (~/PROJECTS)
+  If nonick is False: finds all dir paths with file called fname in them, reads that file for each dir to find the nickname of that Project. Otherwise just lists the subdirectories of projects dir (~/PROJECTS)
 
   
   """
 
   D = info_dict(rootdir = rootdir, projdirname = projdirname,fname = fname, nonick = nonick)
  
-  RP = report()
+  RP = Report()
   RP.echoln("Projects rooted in %s"%projdirname)
   RP.line()
   project_names = D.keys()
@@ -719,25 +730,25 @@ def ls(rootdir = os.environ['HOME'], projdirname = 'PROJECTS',fname = projnickfi
 
 def info(rootdir = os.environ['HOME'], projdirname = 'PROJECTS',fname = projnickfile, nonick = False, verbose = True):
   """
-  Simple function to take inventory of all project directories so that no specific paths need to be used, and projects can be referred to by their nicknames defined in a file called projname in each directory containing the experiment directories.
+  Simple function to take inventory of all Project directories so that no specific paths need to be used, and projects can be referred to by their nicknames defined in a file called projname in each directory containing the experiment directories.
  
   Inputs: 
   rootdir 	dir in which to look for main PROJECTS dir
-  projdirname   dir in which to look for specific project directories. Default is 'PROJECTS'. So by default, projects are expected in '~/PROJECTS/').
-  fname		(default projname) the filename to look for and read the content of to determine nickname of specific project. Disabled with nonick = True
+  projdirname   dir in which to look for specific Project directories. Default is 'PROJECTS'. So by default, projects are expected in '~/PROJECTS/').
+  fname		(default projname) the filename to look for and read the content of to determine nickname of specific Project. Disabled with nonick = True
   
   Outputs:
-  D, dictionary of project nicknames vs full paths		
+  D, dictionary of Project nicknames vs full paths		
     
-  If nonick is False:  finds all dir paths with file called fname in them, reads that file for each dir to find the nickname of that project and builds a dictionary of nicknames vs paths. Otherwise, just takes inventory of all sub directories of projects (~/PROJECTS)
+  If nonick is False:  finds all dir paths with file called fname in them, reads that file for each dir to find the nickname of that Project and builds a dictionary of nicknames vs paths. Otherwise, just takes inventory of all sub directories of projects (~/PROJECTS)
   
   Example of use when projects are in default location ~/PROJECTS/ (spacegrids loaded as sg):
   
   D=sg.info()
   
-  Say this gives keys 'test' and 'TKE'. To open the project with nickname test:
+  Say this gives keys 'test' and 'TKE'. To open the Project with nickname test:
 
-  P = sg.project(D['test'])
+  P = sg.Project(D['test'])
   
   and start working with P. No specific path had to be identified, only a sufficiently specific top.
 
@@ -754,24 +765,24 @@ def info(rootdir = os.environ['HOME'], projdirname = 'PROJECTS',fname = projnick
 
 def info_dict(rootdir = os.environ['HOME'], projdirname = 'PROJECTS',fname = projnickfile, nonick = False):
   """
-  Simple function to take inventory of all project directories so that no specific paths need to be used, and projects can be referred to by their nicknames defined in a file called projname in each directory containing the experiment directories.
+  Simple function to take inventory of all Project directories so that no specific paths need to be used, and projects can be referred to by their nicknames defined in a file called projname in each directory containing the experiment directories.
  
   Inputs: 
   top		(default '~/PROJECTS/') the start dir
   fname		(default projname) the filename to look for and read the content of
   
   Outputs:
-  D, dictionary of project nicknames vs paths		
+  D, dictionary of Project nicknames vs paths		
     
-  If nonick is False:  finds all dir paths with file called fname in them, reads that file for each dir to find the nickname of that project and builds a dictionary of nicknames vs paths. Otherwise, just takes inventory of all sub directories of projects (~/PROJECTS)
+  If nonick is False:  finds all dir paths with file called fname in them, reads that file for each dir to find the nickname of that Project and builds a dictionary of nicknames vs paths. Otherwise, just takes inventory of all sub directories of projects (~/PROJECTS)
   
   Example of use when projects are in default location ~/PROJECTS/ (spacegrids loaded as sg):
   
   D=sg.info_dict()
   
-  Say this gives keys 'test' and 'TKE'. To open the project with nickname test:
+  Say this gives keys 'test' and 'TKE'. To open the Project with nickname test:
 
-  P = sg.project(D['test'])
+  P = sg.Project(D['test'])
   
   and start working with P. No specific path had to be identified, only a sufficiently specific top.
 
@@ -796,7 +807,7 @@ def info_dict(rootdir = os.environ['HOME'], projdirname = 'PROJECTS',fname = pro
   if nonick:
 
     for path in paths:
-      # fname contains the project nickname file (usually projname)       
+      # fname contains the Project nickname file (usually projname)       
       fp = os.path.join(path,fname)
       try:
         with open(fp,'r') as f:
@@ -811,7 +822,7 @@ def info_dict(rootdir = os.environ['HOME'], projdirname = 'PROJECTS',fname = pro
   else:
 
     for path in paths:
-      # fname contains the project nickname file (usually projname)
+      # fname contains the Project nickname file (usually projname)
       fp = os.path.join(path,fname)
       with open(fp,'r') as f:
 # read the first line and make sure the return char \n is deleted.    
